@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 
 import pandas as pd
+from covsirphy.util.error import SubsetNotFoundError
+from covsirphy.util.argument import find_args
 from covsirphy.cleaning.jhu_data import JHUData
 from covsirphy.ode.mbase import ModelBase
 from covsirphy.simulation.simulator import ODESimulator
@@ -146,9 +148,7 @@ class ExampleData(JHUData):
         try:
             return self._specialized_dict[country][province]
         except KeyError:
-            raise KeyError(
-                f"Records of {country} - {province} were not registered."
-            )
+            raise SubsetNotFoundError(country=country, province=province)
 
     def non_dim(self, model=None, country=None, province=None):
         """
@@ -168,9 +168,7 @@ class ExampleData(JHUData):
         try:
             return self.nondim_dict[country][province]
         except KeyError:
-            raise KeyError(
-                f"Records of {country} - {province} were not registered."
-            )
+            raise SubsetNotFoundError(country=country, province=province)
 
     def subset(self, model=None, country=None, province=None, **kwargs):
         """
@@ -202,4 +200,19 @@ class ExampleData(JHUData):
         """
         country, _ = self._model_to_area(
             model=model, country=country, province=province)
+        kwargs = find_args([super().subset], **kwargs)
         return super().subset(country=country, province=province, **kwargs)
+
+    def subset_complement(self, **kwargs):
+        """
+        This is the same as ExampleData.subset().
+        Complement will not be done.
+        """
+        return (self.subset(**kwargs), False)
+
+    def records(self, **kwargs):
+        """
+        This is the same as ExampleData.subset().
+        Complement will not be done.
+        """
+        return (self.subset(**kwargs), False)
