@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from dask import dataframe as dd
 import numpy as np
 import pandas as pd
+from covsirphy.util.error import UnExecutedError
 from covsirphy.cleaning.cbase import CleaningBase
 
 
@@ -14,14 +14,16 @@ class CountryData(CleaningBase):
     Args:
         filename (str or None): filename to read the data
         country (str): country name
+        province (str or None): province name
+
+    Returns:
+        If province name will be set in CountryData.set_variables(), @province will be ignored.
     """
 
-    def __init__(self, filename, country):
-        if filename is None:
-            self._raw = pd.DataFrame()
-        else:
-            self._raw = dd.read_csv(filename).compute()
+    def __init__(self, filename, country, province=None):
+        self._raw = pd.DataFrame() if filename is None else self.load(filename)
         self._country = country
+        self._province = province
         self.province_col = None
         self.var_dict = {}
         self._cleaned_df = pd.DataFrame()
@@ -81,8 +83,7 @@ class CountryData(CleaningBase):
                     - Recovered (int): the number of recovered cases
         """
         if not self.var_dict:
-            raise ValueError(
-                "Please execute CountryData.set_variables() in advance.")
+            raise UnExecutedError("CountryData.set_variables()")
         df = self._raw.copy()
         # Rename the columns
         df = df.rename(self.var_dict, axis=1)
@@ -94,11 +95,14 @@ class CountryData(CleaningBase):
         # Remove empty rows
         df = df.dropna(subset=[self.DATE])
         # Add province column
-        df[self.PROVINCE] = self.UNKNOWN if self.province_col is None else df[self.province_col]
+        if self.province_col is not None:
+            df = df.rename({self.province_col: self.PROVINCE}, axis=1)
+        else:
+            df[self.PROVINCE] = self._province or self.UNKNOWN
         # Values
-        df[self.CI] = df[self.C] - df[self.F] - df[self.R]
-        v_cols = self.VALUE_COLUMNS[:]
+        v_cols = [self.C, self.F, self.R]
         df[v_cols] = df[v_cols].fillna(0).astype(np.int64)
+        df[self.CI] = df[self.C] - df[self.F] - df[self.R]
         # Groupby date and province
         df[self.DATE] = pd.to_datetime(df[self.DATE])
         df = df.groupby([self.DATE, self.PROVINCE]).sum().reset_index()
