@@ -3,16 +3,14 @@
 
 from datetime import datetime, timezone, timedelta
 from pathlib import Path
-from dask import dataframe as dd
-import pandas as pd
-from covsirphy.util.file import save_dataframe
 from covsirphy.cleaning.term import Term
 from covsirphy.cleaning.jhu_data import JHUData
-from covsirphy.cleaning.country_data import CountryData
+from covsirphy.cleaning.japan_data import JapanData
 from covsirphy.cleaning.oxcgrt import OxCGRTData
 from covsirphy.cleaning.population import PopulationData
 from covsirphy.cleaning.covid19datahub import COVID19DataHub
 from covsirphy.cleaning.linelist import LinelistData
+from covsirphy.cleaning.pcr_data import PCRData
 
 
 class DataLoader(Term):
@@ -76,6 +74,8 @@ class DataLoader(Term):
         self.dir_path.mkdir(parents=True, exist_ok=True)
         # COVID-19 Data Hub
         self.covid19dh = None
+        # Cache instances
+        self._linelist_data = None
 
     @staticmethod
     def _last_updated_local(path):
@@ -164,7 +164,16 @@ class DataLoader(Term):
         """
         if local_file is not None:
             return JHUData(filename=local_file)
-        return self._covid19dh(name="jhu", basename=basename, verbose=verbose)
+        # Retrieve JHU data from COVID-19 Data Hub
+        jhu_data = self._covid19dh(
+            name="jhu", basename=basename, verbose=verbose)
+        # Set recovery period for full complement of recovered data in some countries
+        jhu_data.recovery_period = self.linelist(
+            verbose=verbose).recovery_period()
+        # Replace Japan dataset with the government-announced data
+        japan_data = self.japan()
+        jhu_data.replace(japan_data)
+        return jhu_data
 
     def population(self, basename="covid19dh.csv", local_file=None, verbose=1):
         """
@@ -208,7 +217,7 @@ class DataLoader(Term):
             return OxCGRTData(filename=local_file)
         return self._covid19dh(name="oxcgrt", basename=basename, verbose=verbose)
 
-    def japan(self, basename="covid_jpn_total.csv", local_file=None):
+    def japan(self, basename="covid_japan.csv", local_file=None, verbose=1):
         """
         Load the dataset of the number of cases in Japan.
         https://github.com/lisphilar/covid19-sir/tree/master/data
@@ -216,28 +225,14 @@ class DataLoader(Term):
         Args:
             basename (str): basename of the file to save the data
             local_file (str or None): if not None, load the data from this file
+            verbose (int): level of verbosity
 
         Returns:
             covsirphy.CountryData: dataset at country level in Japan
         """
         filename = local_file or self.dir_path.joinpath(basename)
-        if self._download_necessity(filename=filename):
-            url = f"{self.GITHUB_URL}/lisphilar/covid19-sir/master/data/japan/covid_jpn_total.csv"
-            try:
-                df = dd.read_csv(url, blocksize=None).compute()
-            except (ValueError, FileNotFoundError):
-                df = pd.read_csv(url)
-            save_dataframe(df, filename=filename, index=False)
-        japan_data = CountryData(filename=filename, country="Japan")
-        japan_data.citation = "Lisphilar (2020), COVID-19 dataset in Japan, GitHub repository, " \
-            "https://github.com/lisphilar/covid19-sir/data/japan"
-        japan_data.set_variables(
-            date="Date",
-            confirmed="Positive",
-            fatal="Fatal",
-            recovered="Discharged",
-            province=None)
-        return japan_data
+        force = self._download_necessity(filename=filename)
+        return JapanData(filename=filename, force=force, verbose=verbose)
 
     def linelist(self, basename="linelist.csv", verbose=1):
         """
@@ -251,6 +246,37 @@ class DataLoader(Term):
         Returns:
             covsirphy.CountryData: dataset at country level in Japan
         """
-        filename = self.dir_path.joinpath(basename)
-        force = self._download_necessity(filename=filename)
-        return LinelistData(filename=filename, force=force, verbose=verbose)
+        if self._linelist_data is None:
+            filename = self.dir_path.joinpath(basename)
+            force = self._download_necessity(filename=filename)
+            self._linelist_data = LinelistData(
+                filename=filename, force=force, verbose=verbose)
+        return self._linelist_data
+
+    def pcr(self, basename="covid19dh.csv", local_file=None, verbose=1):
+        """
+        Load the dataset regarding the number of tests and confirmed cases,
+        using local CSV file or COVID-19 Data Hub.
+
+        Args:
+            basename (str or None): basename of the file to save the data
+            local_file (str or None): if not None, load the data from this file
+            verbose (int): level of verbosity
+
+        Notes:
+            If @verbose is 2, detailed citation list will be shown when downloading.
+            If @verbose is 1, how to show the list will be explained.
+            Citation of COVID-19 Data Hub will be set as JHUData.citation.
+
+        Returns:
+            covsirphy.PCRData: dataset regarding the number of tests and confirmed cases
+        """
+        if local_file is not None:
+            return PCRData(filename=local_file)
+        # Retrieve JHU data from COVID-19 Data Hub
+        pcr_data = self._covid19dh(
+            name="pcr", basename=basename, verbose=verbose)
+        # Replace Japan dataset with the government-announced data
+        japan_data = self.japan()
+        pcr_data.replace(japan_data)
+        return pcr_data
