@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from dask import dataframe as dd
+from pathlib import Path
 import pandas as pd
 import swifter
+from covsirphy.util.error import SubsetNotFoundError
 from covsirphy.cleaning.cbase import CleaningBase
-from pathlib import Path
 
 
 class LinelistData(CleaningBase):
@@ -28,6 +28,8 @@ class LinelistData(CleaningBase):
     CHRONIC = "Chronic_disease"
     OUTCOME = "Outcome"
     OUTCOME_DATE = "Outcome_date"
+    R_DATE = "Recovered_date"
+    F_DATE = "Fatal_date"
     LINELIST_COLS = [
         CleaningBase.COUNTRY, CleaningBase.PROVINCE,
         HOSPITAL_DATE, CONFIRM_DATE, OUTCOME_DATE,
@@ -37,8 +39,9 @@ class LinelistData(CleaningBase):
 
     def __init__(self, filename, force=False, verbose=1):
         if Path(filename).exists() and not force:
-            self._raw = self._load(filename)
+            self._raw = self.load(filename)
         else:
+            Path(filename).parent.mkdir(exist_ok=True, parents=True)
             self._raw = self._retrieve(filename=filename, verbose=verbose)
         self._cleaned_df = self._cleaning()
         self._citation = "Xu, B., Gutierrez, B., Mekaru, S. et al. " \
@@ -63,7 +66,7 @@ class LinelistData(CleaningBase):
             print(
                 "Retrieving linelist from Open COVID-19 Data Working Group repository: https://github.com/beoutbreakprepared/nCoV2019")
         # Download the dataset
-        df = self._load(self.URL, header=1)
+        df = self.load(self.URL, header=1)
         # Remove un-necessary columns
         df = df.drop(
             [
@@ -82,25 +85,6 @@ class LinelistData(CleaningBase):
         df.to_csv(filename, index=False)
         return df
 
-    @staticmethod
-    def _load(urlpath, header=0):
-        """
-        Load a local/remote file.
-
-        Args:
-            urlpath (str or pathlib.Path): filename or URL
-            header (int): row number of the header
-
-        Returns:
-            pd.DataFrame: raw dataset
-        """
-        kwargs = {
-            "low_memory": False, "dtype": "object", "header": header, }
-        try:
-            return dd.read_csv(urlpath, blocksize=None, **kwargs).compute()
-        except (FileNotFoundError, UnicodeDecodeError):
-            return pd.read_csv(urlpath, **kwargs)
-
     def _cleaning(self):
         """
         Perform data cleaning of the raw data.
@@ -132,6 +116,7 @@ class LinelistData(CleaningBase):
         for col in [self.HOSPITAL_DATE, self.CONFIRM_DATE, self.OUTCOME_DATE]:
             df[col] = pd.to_datetime(
                 df[col], infer_datetime_format=True, errors="coerce")
+        df = df.loc[~df[self.CONFIRM_DATE].isna()]
         # Outcome
         df[self.C] = ~df[self.CONFIRM_DATE].isna()
         df[self.R] = df[self.OUTCOME].str.lower().isin(
@@ -158,6 +143,93 @@ class LinelistData(CleaningBase):
         # Select columns
         return df.loc[:, self.LINELIST_COLS]
 
+    def subset(self, country, province=None):
+        """
+        Return subset of the country/province.
+
+        Args:
+            country (str): country name or ISO3 code
+            province (str or None): province name
+
+        Returns:
+            pandas.DataFrame
+                Index:
+                    reset index
+                Columns:
+                    - Hospitalized_date (pandas.TimeStamp or NT)
+                    - Confirmation_date (pandas.TimeStamp or NT)
+                    - Outcome_date (pandas.TimeStamp or NT)
+                    - Confirmed (bool)
+                    - Infected (bool)
+                    - Recovered (bool)
+                    - Fatal (bool)
+                    - Symtoms (str)
+                    - Chronic_disease (str)
+                    - Age (int or None)
+                    - Sex (str)
+        """
+        df = self._cleaned_df.copy()
+        # Subset by country name
+        country = self.ensure_country_name(country)
+        df = df.loc[df[self.COUNTRY] == country]
+        # Subset by province name
+        if province not in (None, self.UNKNOWN):
+            df = df.loc[df[self.PROVINCE] == province]
+        # Check records are registered
+        country_alias = self.ensure_country_name(country)
+        if df.empty:
+            raise SubsetNotFoundError(
+                country=country, country_alias=country_alias, province=province)
+        df = df.drop([self.COUNTRY, self.PROVINCE], axis=1)
+        return df.reset_index(drop=True)
+
+    def closed(self, outcome="Recovered"):
+        """
+        Return subset of global outcome data (recovered/fatal).
+
+        Args:
+            outcome (str): 'Recovered' or 'Fatal'
+
+        Returns:
+            pandas.DataFrame
+                Index:
+                    reset index
+                Columns:
+                    - Country (str): country name
+                    - Province (str): province name or "-"
+                    - Hospitalized_date (pandas.TimeStamp or NT)
+                    - Confirmation_date (pandas.TimeStamp)
+                    - Recovered_date (pandas.TimeStamp): if outcome is Recovered
+                    - Fatal_date (pandas.TimeStamp): if outcome is Fatal
+                    - Symptoms (str)
+                    - Chronic_disease (str)
+                    - Age (int or None)
+                    - Sex (str)
+        """
+        column_dict = {self.R: self.R_DATE, self.F: self.F_DATE}
+        if outcome not in column_dict:
+            raise KeyError(
+                f"@outcome should be selected from {self.R} or {self.F}, but {outcome} was applied.")
+        df = self._cleaned_df.copy()
+        df = df.loc[df[outcome]]
+        # Subset by date
+        df = df.loc[df[self.CONFIRM_DATE] < df[self.OUTCOME_DATE]]
+        # Column names
+        df = df.rename({self.OUTCOME_DATE: column_dict[outcome]}, axis=1)
+        df = df.drop([self.C, self.CI, self.F, self.R], axis=1)
+        return df.reset_index(drop=True)
+
+    def recovery_period(self):
+        """
+        Calculate median value of recovery period (from confirmation to recovery).
+
+        Returns:
+            int: recovery period [days]
+        """
+        df = self.closed(outcome=self.R)
+        series = (df[self.R_DATE] - df[self.CONFIRM_DATE]).dt.days
+        return int(series.median())
+
     def total(self):
         """
         This is not defined for this child class.
