@@ -32,12 +32,12 @@ class SIR(ModelBase):
     VARS_INCLEASE = [ModelBase.FR]
     # Example set of parameters and initial values
     EXAMPLE = {
-        "step_n": 180,
-        "population": 1_000_000,
-        "param_dict": {
+        ModelBase.STEP_N: 180,
+        ModelBase.N.lower(): 1_000_000,
+        ModelBase.PARAM_DICT: {
             "rho": 0.2, "sigma": 0.075,
         },
-        "y0_dict": {
+        ModelBase.Y0_DICT: {
             ModelBase.S: 999_000, ModelBase.CI: 1000, ModelBase.FR: 0,
         },
     }
@@ -92,6 +92,7 @@ class SIR(ModelBase):
         df = cls.ensure_dataframe(
             taufree_df, name="taufree_df", columns=[cls.TS, *cls.VARIABLES]
         )
+        df = df.loc[(df[cls.S] > 0) & (df[cls.CI] > 0)]
         n, t, s, i, r = population, df[cls.TS], df[cls.S], df[cls.CI], df[cls.FR]
         # rho = - n * (dS/dt) / S / I
         rho_series = 0 - n * s.diff() / t.diff() / s / i
@@ -99,7 +100,7 @@ class SIR(ModelBase):
         sigma_series = r.diff() / t.diff() / i
         # Calculate quantile
         _dict = {
-            k: v.quantile(cls.QUANTILE_RANGE)
+            k: tuple(v.quantile(cls.QUANTILE_RANGE).clip(0, 1))
             for (k, v) in zip(["rho", "sigma"], [rho_series, sigma_series])
         }
         return _dict
