@@ -4,7 +4,7 @@
 from itertools import groupby
 from operator import itemgetter
 import pandas as pd
-from covsirphy.util.error import deprecate
+from covsirphy.util.error import deprecate, UnExecutedError
 from covsirphy.util.plotting import line_plot
 from covsirphy.cleaning.jhu_data import JHUData
 from covsirphy.cleaning.population import PopulationData
@@ -185,8 +185,7 @@ class PolicyMeasures(Term):
             [
                 unit.set_id(
                     country=self.jhu_data.country_to_iso3(country),
-                    phase=f"{self.num2str(num):>4}"
-                )
+                    phase=f"{self.num2str(num):>4}")
                 for (num, unit) in enumerate(self.scenario_dict[country][self.MAIN]) if unit]
             for country in self._countries
         ]
@@ -194,10 +193,10 @@ class PolicyMeasures(Term):
         # Parameter estimation
         mp_estimator = MPEstimator(
             jhu_data=self.jhu_data, population_data=self.population_data,
-            model=model, tau=self.tau, **kwargs
-        )
+            model=model, tau=self.tau, **kwargs)
         mp_estimator.add(units)
-        results = mp_estimator.run(n_jobs=n_jobs, **kwargs)
+        results = mp_estimator.run(
+            n_jobs=n_jobs, auto_complement=True, **kwargs)
         # Register the results
         for country in self._countries:
             new_units = [
@@ -282,8 +281,7 @@ class PolicyMeasures(Term):
                 Values: parameter values
         """
         if self.model is None:
-            raise ValueError(
-                "PolicyMeasures.estimate(model) must be done in advance.")
+            raise UnExecutedError("PolicyMeasures.estimate(model)")
         # Get parameter/Rt/data parameter value of each date
         df = self.summary().reset_index().replace(self.UNKNOWN, None)
         df[self.START] = pd.to_datetime(
