@@ -43,7 +43,7 @@ class TestPhaseSeries(object):
         base_cols = [Term.TENSE, Term.START, Term.END, Term.N]
         assert set(df.columns) == set(base_cols)
         assert series.to_dict()["0th"]["Type"] == Term.PAST
-        assert len(df) == 6
+        first_len = len(df)
         assert set(df.loc["3rd", :].tolist()) == set(
             [Term.PAST, "27May2020", "01Aug2020", 123998518])
         assert set(df.loc["4th", :].tolist()) == set(
@@ -51,16 +51,16 @@ class TestPhaseSeries(object):
         # Disable/enable a phase
         series.disable("0th")
         assert "0th" not in series.to_dict()
-        assert len(series) == 5
-        assert len([unit for unit in series]) == 6
-        assert len([unit for unit in series if unit]) == 5
+        assert len(series) == first_len - 1
+        assert len([unit for unit in series]) == first_len
+        assert len([unit for unit in series if unit]) == first_len - 1
         series.enable("0th")
         assert "0th" in series.to_dict()
-        assert len(series) == 6
+        assert len(series) == first_len
         # Clear future phases: 4th and 5th will be deleted
         series.clear(include_past=False)
         assert "4th" not in series.to_dict()
-        assert len(series) == 4
+        assert len(series) == first_len - 2
         assert series
         # Clear all phases
         series.clear(include_past=True)
@@ -69,6 +69,8 @@ class TestPhaseSeries(object):
         # Filling past phases: 0th
         series.add()
         assert len(series) == 1
+        # Last phase
+        assert series.unit(phase="last")
 
     @pytest.mark.parametrize("country", ["Japan"])
     def test_trend(self, jhu_data, population_data, country):
@@ -78,23 +80,12 @@ class TestPhaseSeries(object):
         population = population_data.value(country)
         sr_df = jhu_data.to_sr(country=country, population=population)
         series = PhaseSeries("01Apr2020", "01Aug2020", population)
-        # Add a phase with specified end date
-        series.add(end_date="22Apr2020")
         # S-R trend analysis
-        series.trend(sr_df, set_phases=False, area=None)
-        series.trend(sr_df, set_phases=False, area=None, show_figure=False)
-        assert len(series) == 1
-        assert set(series.to_dict()) == set(["0th"])
-        # S-R trend analysis and set phases
         series.trend(sr_df)
-        series.trend(sr_df, show_figure=False)
-        # Summary
-        assert len(series) == 7
-        # Last phase
-        assert series.unit(phase="last") == series.unit(phase="6th")
+        series.trend_show(sr_df=sr_df, area=None, filename=None)
         # Un-registered phase
         with pytest.raises(KeyError):
-            series.unit("10th")
+            series.unit("100th")
 
     @pytest.mark.parametrize("country", ["Japan"])
     def test_add_phase_with_model(self, jhu_data, population_data, country):
@@ -102,16 +93,17 @@ class TestPhaseSeries(object):
         population = population_data.value(country)
         sr_df = jhu_data.to_sr(country=country, population=population)
         series = PhaseSeries("01Apr2020", "01Aug2020", population)
-        series.trend(sr_df, show_figure=False)
+        series.trend(sr_df)
         # Add future phase with model and tau
         series.add(end_date="01Sep2020", model=SIR, tau=360)
         series.add(end_date="01Oct2020")
-        assert series.to_dict()["7th"][Term.ODE] == SIR.NAME
-        assert series.to_dict()["8th"][Term.TAU] == 360
+        length = len(series)
+        assert series.to_dict()[Term.num2str(length - 2)][Term.ODE] == SIR.NAME
+        assert series.to_dict()[Term.num2str(length - 1)][Term.TAU] == 360
         series.add(end_date="01Nov2020", rho=0.006)
         series.add(end_date="01Dec2020", sigma=0.011)
-        assert series.to_dict()["10th"][Term.RT] == 0.55
-        assert series.to_dict()["10th"]["1/beta [day]"] == 41
+        assert series.to_dict()[Term.num2str(length + 1)][Term.RT] == 0.55
+        assert series.to_dict()[Term.num2str(length + 1)]["1/beta [day]"] == 41
 
     @pytest.mark.parametrize("country", ["Japan"])
     def test_delete_phase(self, jhu_data, population_data, country):
@@ -119,12 +111,12 @@ class TestPhaseSeries(object):
         population = population_data.value(country)
         sr_df = jhu_data.to_sr(country=country, population=population)
         series = PhaseSeries("01Apr2020", "01Aug2020", population)
-        series.trend(sr_df, show_figure=False)
-        assert len(series) == 7
+        series.trend(sr_df)
+        first_len = len(series)
         # Deletion of 0th phase is the same as disabling 0th phase
         series.delete("0th")
         series.enable("0th")
-        assert len(series) == 7
+        assert len(series) == first_len
         assert "5th" in series.to_dict()
         # Delete phase (not the last registered phase)
         new_second = PhaseUnit(
@@ -132,7 +124,7 @@ class TestPhaseSeries(object):
             series.unit("3rd").end_date,
             series.unit("2nd").population)
         series.delete("3rd")
-        assert len(series) == 6
+        assert len(series) == first_len - 1
         assert series.unit("2nd") == new_second
         # Delete the last phase
         old_last = series.unit("last")
@@ -144,36 +136,39 @@ class TestPhaseSeries(object):
     def test_replace(self, jhu_data, population_data, country):
         # Setting
         population = population_data.value(country)
-        sr_df = jhu_data.to_sr(country=country, population=population)
         series = PhaseSeries("01Apr2020", "01Aug2020", population)
-        series.trend(sr_df, show_figure=False)
+        series.add(end_date="01May2020")
+        series.add(end_date="01Jun2020")
+        series.add(end_date="01Jul2020")
+        series.add()
         # Replace one old phase with one new phase
-        unit_old = series.unit("2nd")
+        unit_old = series.unit("0th")
         unit_new = PhaseUnit(
             unit_old.start_date, unit_old.end_date, population
         )
         unit_new.set_ode(tau=360)
-        series.replace("2nd", unit_new)
-        assert series.unit("2nd") == unit_new
+        series.replace("0th", unit_new)
+        assert series.unit("0th") == unit_new
         # Replace one old phase with two new phases
-        unit_old = series.unit("2nd")
+
+        unit_old = series.unit("1st")
         change_date = Term.date_change(unit_old.end_date, days=-7)
         unit_pre = PhaseUnit(
             unit_old.start_date, Term.yesterday(change_date), population)
         unit_pre.set_ode(tau=360)
         unit_fol = PhaseUnit(change_date, unit_old.end_date, population)
         unit_fol.set_ode(tau=360)
-        series.replaces(phase="2nd", new_list=[unit_pre, unit_fol])
-        print(series.unit("2nd"), unit_pre)
-        assert series.unit("2nd") == unit_pre
-        assert series.unit("3rd") == unit_fol
+        series.replaces(phase="1st", new_list=[unit_pre, unit_fol])
+        print(series.unit("1st"), unit_pre)
+        assert series.unit("1st") == unit_pre
+        assert series.unit("2nd") == unit_fol
         # TypeError of new_list
         with pytest.raises(TypeError):
-            series.replaces(phase="2nd", new_list=[unit_pre, Term])
+            series.replaces(phase="3rd", new_list=[unit_pre, Term])
         # ValueError with tense
         with pytest.raises(ValueError):
             future_unit = PhaseUnit("01Sep2020", "01Dec2020", population)
-            series.replaces(phase="2nd", new_list=[future_unit])
+            series.replaces(phase="3rd", new_list=[future_unit])
         # Add phase without deletion of any phases
         new1 = PhaseUnit("02Aug2020", "01Sep2020", population)
         new2 = PhaseUnit("02Sep2020", "01Oct2020", population)
